# AirData UAV Objects
[![PyPI version](https://badge.fury.io/py/AirDataUAV.svg)](https://badge.fury.io/py/AirDataUAV)  

Started to create a neat interface for the converted data from [https://airdata.com/](https://airdata.com/).

## Current data columns
 
### Done
 - time(millisecond)  
 - latitude  
 - longitude  
 - height_above_takeoff(feet)  
 - xSpeed(mph)  
 - ySpeed(mph)  
 - zSpeed(mph)
 - speed(mph)  
 
### Todo

 - datetime(utc)  
 - height_above_ground_at_drone_location(feet)  
 - ground_elevation_at_drone_location(feet)  
 - altitude_above_seaLevel(feet)  
 - height_sonar(feet)  
 - speed(mph)  
 - distance(feet)  
 - satellites  
 - gpslevel  
 - voltage(v)  
 - max_altitude(feet)  
 - max_ascent(feet)  
 - max_speed(mph)  
 - max_distance(feet)  
 - compass_heading(degrees)  
 - pitch(degrees)  
 - roll(degrees)  
 - isPhoto  
 - isVideo  
 - rc_elevator  
 - rc_aileron  
 - rc_throttle  
 - rc_rudder  
 - gimbal_heading(degrees)  
 - gimbal_pitch(degrees)  
 - battery_percent  
 - voltageCell1  
 - voltageCell2  
 - voltageCell3  
 - voltageCell4  
 - voltageCell5  
 - voltageCell6  
 - current(A)  
 - battery_temperature(f)  
 - altitude(feet)  
 - ascent(feet)  
 - flycStateRaw  
 - flycState  
 - message
